@@ -31,4 +31,9 @@ git init all-untracked
   >a
   mkdir d
   >d/a
+)
+
+git init empty-core-excludes
+(cd empty-core-excludes
+  echo $'[core]\n\texcludesFile = ' >> .git/config
 )
\ No newline at end of file
