@@ -16,5 +16,7 @@ mod remote;
 mod repository;
 #[cfg(feature = "revision")]
 mod revision;
+#[cfg(feature = "status")]
+mod status;
 #[cfg(feature = "attributes")]
 mod submodule;
