@@ -94,14 +94,6 @@ static GIT_CONFIG: &[Record] = &[
         config: "core.loosecompression",
         usage: Planned("")
     },
-    Record {
-        config: "core.protectHFS",
-        usage: Planned("relevant for checkout on MacOS")
-    },
-    Record {
-        config: "core.protectNTFS",
-        usage: NotPlanned("lack of demand")
-    },
     Record {
         config: "core.sparseCheckout",
         usage: Planned("we want to support huge repos and be the fastest in doing so")
